########################## Subroutine for Grading UndetCoeff##################
$mycheckerOutside = sub  {
    my ( $correct, $student, $self ) = @_;
    my $context = Context()->copy;
    # line below is necessary so  exponentials don't get too big
    # limits need to be adjusted differently when solution has
    # growing exponentials or when there are only trig functions
    # e.g. for e^{\pm 7t} need [-0.1, 0.1]
    # but this will cause erroneous grading for just trigs
    # Should eventually include limits as ARG
    # or at least set them differently for each sub-problem
    $context->variables->set($var => {limits => [-1, 1]});
    $context->flags->set(no_parameters=>0);
    $student = Formula($context,$student); # apparently not necessary 

    ################
    # We check that each c_i term in the correct solution ($y[$i] below)
    # is a linear combination of the terms in the student
    # solution ($st[$i] below). Thus the student must have included all the
    # necessary terms. 
    
    ################################################
    ### count the number of constants
    ### in the correct solution
    ### which we assume uses c0, c1, c2 etc.
    ### not skipping any c_i
    ### then check that each c_i is present in the
    ### student answer
    my $AnswerStr = $correct->string;
    my $studentStr = $student->string;

    my $numcs = 0;
    while ($AnswerStr =~ m|c~~d|g) { $numcs++ }
    for (my $i=0;$i < $numcs;$i++) {
	unless ($studentStr =~ m|c$i|g) {
	    Value->Error("You need a c$i term")
	};
    }
    
    ##################################################
    # Now extract terms multiplied by each c_i from the
    # correct answer and from the student answer
    # I could check 2nd derivatives to make sure
    # that the dependance on c_i's was linear
    # but am ignoring that for now.
    # Simultaneously, change the c_i's in the student
    # answer to d_i's which are parameters.
    ################################################## 
    my $studentHstr = "0 ";
    for (my $i =0; $i < $numcs; $i++) {
    	$context->variables->add("D$i" =>'Parameter');
    	$d[$i] = Formula($context,"D$i");
	$y[$i] = Formula($context,$correct->D("c$i"));
	$st[$i] = $student->D("c$i");
	$studentHstr = $studentHstr . " + $d[$i]*$st[$i]";}

    #### extract inhomogeneous term by setting c_i's to 0
    my $yforced = Formula($context,$correct);
    my $stforced = Formula($context,$student);
    for (my $i =0; $i < $numcs; $i++) {
	$yforced = Formula($context,$yforced->substitute("c$i"=>0));
	$stforced = Formula($context,$stforced->substitute("c$i"=>0));}
    ####

    ###### Finally construct MathObject with parameters
    my $studentH = Formula($context,$studentHstr);
    my $studentwp = $studentH + $stforced;

    ################################################
    # Student answer is correct, iff every term $y[$i]
    # is a linear combination of $st[i$];
    # i.e. if there exist parameters D_i solving
    # $studentH == $y[$i] for all $y[$i]
    # If adaptive parameters can't be found
    # the student answer is incorrect.
    # The line begiing with
    # $result = Parser::Eval below "catches" the
    # error message tha occurs when the
    # matrix used to solve for the parameters
    # is singular and simply doesn't return $result
    # in that case
    ################################################
    for (my $i =0; $i < $numcs; $i++) {
	my $result = Parser::Eval(sub {$studentH == $y[$i] ? 1 : 0});
	unless (defined($result)) { 
	   Value->Error(
		"Your terms are linearly dependent"
	   );
	};
	if ($result != 1) {
	    Value->Error(
		"Your solution space does not include $y[$i]"
	    )
	};
     }; 
    ################################################
    # Check forcing term similarly
    # Note: If it gets this far, $result is defined
    # so we don't need to check that again
    ################################################

  
    if ($studentwp != $yforced) {
	Value->Error(
		"Particular Solution Wrong.\n
	    yforced is $yforced\n
	    stforced is $stforced\n
                 y1 is $y[0]\n
                 y2 is $y[1]\n
	         st1 is $st[0]\n
                 st2 is $st[1]"
	)
    };
### if we get this far its correct
 $self->{ans_message} =
		"I used Outside checker";	  

    return(1)
};
#####################end of subroutine for Grading######################
